[Mesa-dev] [PATCH 01/12] i965: Handle 16x MSAA in IMS dimension munging code.

Neil Roberts neil at linux.intel.com
Thu Sep 17 09:00:03 PDT 2015


From: Kenneth Graunke <kenneth at whitecape.org>

Signed-off-by: Kenneth Graunke <kenneth at whitecape.org>
Reviewed-by: Neil Roberts <neil at linux.intel.com>
---
 src/mesa/drivers/dri/i965/intel_mipmap_tree.c | 8 ++++++--
 1 file changed, 6 insertions(+), 2 deletions(-)

diff --git a/src/mesa/drivers/dri/i965/intel_mipmap_tree.c b/src/mesa/drivers/dri/i965/intel_mipmap_tree.c
index 2150708..0cb0632 100644
--- a/src/mesa/drivers/dri/i965/intel_mipmap_tree.c
+++ b/src/mesa/drivers/dri/i965/intel_mipmap_tree.c
@@ -395,9 +395,13 @@ intel_miptree_create_layout(struct brw_context *brw,
             width0 = ALIGN(width0, 2) * 4;
             height0 = ALIGN(height0, 2) * 2;
             break;
+         case 16:
+            width0 = ALIGN(width0, 2) * 4;
+            height0 = ALIGN(height0, 2) * 4;
+            break;
          default:
             /* num_samples should already have been quantized to 0, 1, 2, 4, or
              * 8.
              */
             unreachable("not reached");
          }
@@ -395,9 +395,13 @@ intel_miptree_create_layout(struct brw_context *brw,
          default:
-            /* num_samples should already have been quantized to 0, 1, 2, 4, or
-             * 8.
+            /* num_samples should already have been quantized to 0, 1, 2, 4, 8
+             * or 16.
              */
             unreachable("not reached");
-- 
1.9.3



More information about the mesa-dev mailing list